@@ -17,8 +17,15 @@ class IdealistaAPI(object):
 
     def _add_props_to_xml(self, parent, values_dict):
         for key in values_dict:
-            key_xml = SubElement(parent, key)
+            if key == '_in':
+                continue
+
             value = values_dict[key]
+            try:
+                value_in = value['_in']
+            except:
+                value_in = {}
+            key_xml = SubElement(parent, key, value_in)
 
             if value is list:
                 for item in value:
@@ -48,5 +55,7 @@ class IdealistaAPI(object):
             property_xml = SubElement(properties_xml, 'property')
             self._add_props_to_xml(property_xml, property)
 
+        return clients
+
     def get_xml(self, property_list):
         return self._make_xml(property_list)
